@@ -3,11 +3,15 @@
 
 #pragma once
 
+#include <cassert>
+#include <cstddef>
 #include <iterator>
 #include <limits>
 #include <ostream>
 #include <stdexcept>
+#include <sys/types.h>
 #include <vector>
+#include <stdint.h>
 
 namespace rapidfuzz::detail {
 
@@ -56,6 +60,9 @@ template <typename Iter>
 class Range {
     Iter _first;
     Iter _last;
+    // todo we might not want to cache the size for iterators
+    // that can can retrieve the size in O(1) time
+    size_t _size;
 
 public:
     using value_type = typename std::iterator_traits<Iter>::value_type;
@@ -63,11 +70,21 @@ public:
     using reverse_iterator = std::reverse_iterator<iterator>;
 
     constexpr Range(Iter first, Iter last) : _first(first), _last(last)
-    {}
+    {
+        assert(std::distance(_first, _last) >= 0);
+        _size = static_cast<size_t>(std::distance(_first, _last));
+    }
+
+    constexpr Range(Iter first, Iter last, size_t size) : _first(first), _last(last), _size(size)
+    {
+    }
 
     template <typename T>
     constexpr Range(T& x) : _first(to_begin(x)), _last(to_end(x))
-    {}
+    {
+        assert(std::distance(_first, _last) >= 0);
+        _size = static_cast<size_t>(std::distance(_first, _last));
+    }
 
     constexpr iterator begin() const noexcept
     {
@@ -87,10 +104,11 @@ public:
         return reverse_iterator(begin());
     }
 
-    constexpr ptrdiff_t size() const
+    constexpr size_t size() const
     {
-        return std::distance(_first, _last);
+        return _size;
     }
+
     constexpr bool empty() const
     {
         return size() == 0;
@@ -104,37 +122,44 @@ public:
         typename... Dummy, typename IterCopy = Iter,
         typename = std::enable_if_t<std::is_base_of_v<
             std::random_access_iterator_tag, typename std::iterator_traits<IterCopy>::iterator_category>>>
-    constexpr decltype(auto) operator[](ptrdiff_t n) const
+    constexpr decltype(auto) operator[](size_t n) const
     {
-        return _first[n];
+        return _first[static_cast<ptrdiff_t>(n)];
     }
 
-    constexpr void remove_prefix(ptrdiff_t n)
+    constexpr void remove_prefix(size_t n)
     {
         if constexpr (std::is_base_of_v<std::random_access_iterator_tag,
                                         typename std::iterator_traits<Iter>::iterator_category>)
-            _first += n;
+            _first += static_cast<ptrdiff_t>(n);
         else
-            for (ptrdiff_t i = 0; i < n; ++i)
+            for (size_t i = 0; i < n; ++i)
                 _first++;
+
+        _size -= n;
     }
-    constexpr void remove_suffix(ptrdiff_t n)
+    constexpr void remove_suffix(size_t n)
     {
         if constexpr (std::is_base_of_v<std::random_access_iterator_tag,
                                         typename std::iterator_traits<Iter>::iterator_category>)
-            _last -= n;
+            _last -= static_cast<ptrdiff_t>(n);
         else
-            for (ptrdiff_t i = 0; i < n; ++i)
+            for (size_t i = 0; i < n; ++i)
                 _last--;
+
+        _size -= n;
     }
 
-    constexpr Range subseq(ptrdiff_t pos = 0, ptrdiff_t count = std::numeric_limits<ptrdiff_t>::max())
+    constexpr Range subseq(size_t pos = 0, size_t count = std::numeric_limits<size_t>::max())
     {
         if (pos > size()) throw std::out_of_range("Index out of range in Range::substr");
 
-        auto start = _first + pos;
-        if (std::distance(start, _last) < count) return {start, _last};
-        return {start, start + count};
+        Range res = *this;
+        res.remove_prefix(pos);
+        if(count < res.size())
+            res.remove_suffix(res.size() - count);
+
+        return res;
     }
 
     constexpr decltype(auto) front() const
@@ -149,7 +174,7 @@ public:
 
     constexpr Range<reverse_iterator> reversed() const
     {
-        return {rbegin(), rend()};
+        return {rbegin(), rend(), _size};
     }
 
     friend std::ostream& operator<<(std::ostream& os, const Range& seq)
