@@ -2,9 +2,9 @@
 #include "cpp_common.hpp"
 
 /* Levenshtein */
-static inline int64_t levenshtein_distance_func(const RF_String& str1, const RF_String& str2,
-                                                int64_t insertion, int64_t deletion, int64_t substitution,
-                                                int64_t score_cutoff, int64_t score_hint)
+static inline size_t levenshtein_distance_func(const RF_String& str1, const RF_String& str2,
+                                                size_t insertion, size_t deletion, size_t substitution,
+                                                size_t score_cutoff, size_t score_hint)
 {
     return visitor(str1, str2, [&](auto s1, auto s2) {
         return rf::levenshtein_distance(s1, s2, {insertion, deletion, substitution}, score_cutoff,
@@ -20,11 +20,11 @@ static inline bool LevenshteinDistanceInit(RF_ScorerFunc* self, const RF_Kwargs*
 #ifdef RAPIDFUZZ_X64
     if (weights.insert_cost == 1 && weights.delete_cost == 1 && weights.replace_cost == 1) {
         if (str_count != 1)
-            return multi_distance_init<rf::experimental::MultiLevenshtein, int64_t>(self, str_count, str);
+            return multi_distance_init<rf::experimental::MultiLevenshtein, size_t>(self, str_count, str);
     }
 #endif
 
-    return distance_init<rf::CachedLevenshtein, int64_t>(self, str_count, str, weights);
+    return distance_init<rf::CachedLevenshtein, size_t>(self, str_count, str, weights);
 }
 static inline bool LevenshteinMultiStringSupport(const RF_Kwargs* kwargs)
 {
@@ -38,8 +38,8 @@ static inline bool LevenshteinMultiStringSupport(const RF_Kwargs* kwargs)
 }
 
 static inline double levenshtein_normalized_distance_func(const RF_String& str1, const RF_String& str2,
-                                                          int64_t insertion, int64_t deletion,
-                                                          int64_t substitution, double score_cutoff,
+                                                          size_t insertion, size_t deletion,
+                                                          size_t substitution, double score_cutoff,
                                                           double score_hint)
 {
     return visitor(str1, str2, [&](auto s1, auto s2) {
@@ -63,9 +63,9 @@ static inline bool LevenshteinNormalizedDistanceInit(RF_ScorerFunc* self, const
     return normalized_distance_init<rf::CachedLevenshtein, double>(self, str_count, str, weights);
 }
 
-static inline int64_t levenshtein_similarity_func(const RF_String& str1, const RF_String& str2,
-                                                  int64_t insertion, int64_t deletion, int64_t substitution,
-                                                  int64_t score_cutoff, int64_t score_hint)
+static inline size_t levenshtein_similarity_func(const RF_String& str1, const RF_String& str2,
+                                                  size_t insertion, size_t deletion, size_t substitution,
+                                                  size_t score_cutoff, size_t score_hint)
 {
     return visitor(str1, str2, [&](auto s1, auto s2) {
         return rf::levenshtein_similarity(s1, s2, {insertion, deletion, substitution}, score_cutoff,
@@ -81,16 +81,16 @@ static inline bool LevenshteinSimilarityInit(RF_ScorerFunc* self, const RF_Kwarg
 #ifdef RAPIDFUZZ_X64
     if (weights.insert_cost == 1 && weights.delete_cost == 1 && weights.replace_cost == 1) {
         if (str_count != 1)
-            return multi_similarity_init<rf::experimental::MultiLevenshtein, int64_t>(self, str_count, str);
+            return multi_similarity_init<rf::experimental::MultiLevenshtein, size_t>(self, str_count, str);
     }
 #endif
 
-    return similarity_init<rf::CachedLevenshtein, int64_t>(self, str_count, str, weights);
+    return similarity_init<rf::CachedLevenshtein, size_t>(self, str_count, str, weights);
 }
 
 static inline double levenshtein_normalized_similarity_func(const RF_String& str1, const RF_String& str2,
-                                                            int64_t insertion, int64_t deletion,
-                                                            int64_t substitution, double score_cutoff,
+                                                            size_t insertion, size_t deletion,
+                                                            size_t substitution, double score_cutoff,
                                                             double score_hint)
 {
     return visitor(str1, str2, [&](auto s1, auto s2) {
@@ -115,8 +115,8 @@ static inline bool LevenshteinNormalizedSimilarityInit(RF_ScorerFunc* self, cons
 }
 
 /* Damerau Levenshtein */
-static inline int64_t damerau_levenshtein_distance_func(const RF_String& str1, const RF_String& str2,
-                                                        int64_t score_cutoff)
+static inline size_t damerau_levenshtein_distance_func(const RF_String& str1, const RF_String& str2,
+                                                        size_t score_cutoff)
 {
     return visitor(str1, str2, [&](auto s1, auto s2) {
         return rf::experimental::damerau_levenshtein_distance(s1, s2, score_cutoff);
@@ -126,7 +126,7 @@ static inline int64_t damerau_levenshtein_distance_func(const RF_String& str1, c
 static inline bool DamerauLevenshteinDistanceInit(RF_ScorerFunc* self, const RF_Kwargs*, int64_t str_count,
                                                   const RF_String* str)
 {
-    return distance_init<rf::experimental::CachedDamerauLevenshtein, int64_t>(self, str_count, str);
+    return distance_init<rf::experimental::CachedDamerauLevenshtein, size_t>(self, str_count, str);
 }
 
 static inline double damerau_levenshtein_normalized_distance_func(const RF_String& str1,
@@ -142,8 +142,8 @@ static inline bool DamerauLevenshteinNormalizedDistanceInit(RF_ScorerFunc* self,
     return normalized_distance_init<rf::experimental::CachedDamerauLevenshtein, double>(self, str_count, str);
 }
 
-static inline int64_t damerau_levenshtein_similarity_func(const RF_String& str1, const RF_String& str2,
-                                                          int64_t score_cutoff)
+static inline size_t damerau_levenshtein_similarity_func(const RF_String& str1, const RF_String& str2,
+                                                          size_t score_cutoff)
 {
     return visitor(str1, str2, [&](auto s1, auto s2) {
         return rf::experimental::damerau_levenshtein_similarity(s1, s2, score_cutoff);
@@ -153,7 +153,7 @@ static inline int64_t damerau_levenshtein_similarity_func(const RF_String& str1,
 static inline bool DamerauLevenshteinSimilarityInit(RF_ScorerFunc* self, const RF_Kwargs*, int64_t str_count,
                                                     const RF_String* str)
 {
-    return similarity_init<rf::experimental::CachedDamerauLevenshtein, int64_t>(self, str_count, str);
+    return similarity_init<rf::experimental::CachedDamerauLevenshtein, size_t>(self, str_count, str);
 }
 
 static inline double damerau_levenshtein_normalized_similarity_func(const RF_String& str1,
@@ -172,8 +172,8 @@ static inline bool DamerauLevenshteinNormalizedSimilarityInit(RF_ScorerFunc* sel
 }
 
 /* Hamming */
-static inline int64_t hamming_distance_func(const RF_String& str1, const RF_String& str2, bool pad,
-                                            int64_t score_cutoff)
+static inline size_t hamming_distance_func(const RF_String& str1, const RF_String& str2, bool pad,
+                                            size_t score_cutoff)
 {
     return visitor(str1, str2, [&](auto s1, auto s2) {
         return rf::hamming_distance(s1, s2, pad, score_cutoff);
@@ -184,7 +184,7 @@ static inline bool HammingDistanceInit(RF_ScorerFunc* self, const RF_Kwargs* kwa
 {
     bool pad = *static_cast<bool*>(kwargs->context);
 
-    return distance_init<rf::CachedHamming, int64_t>(self, str_count, str, pad);
+    return distance_init<rf::CachedHamming, size_t>(self, str_count, str, pad);
 }
 
 static inline double hamming_normalized_distance_func(const RF_String& str1, const RF_String& str2, bool pad,
@@ -202,8 +202,8 @@ static inline bool HammingNormalizedDistanceInit(RF_ScorerFunc* self, const RF_K
     return normalized_distance_init<rf::CachedHamming, double>(self, str_count, str, pad);
 }
 
-static inline int64_t hamming_similarity_func(const RF_String& str1, const RF_String& str2, bool pad,
-                                              int64_t score_cutoff)
+static inline size_t hamming_similarity_func(const RF_String& str1, const RF_String& str2, bool pad,
+                                              size_t score_cutoff)
 {
     return visitor(str1, str2, [&](auto s1, auto s2) {
         return rf::hamming_similarity(s1, s2, pad, score_cutoff);
@@ -214,7 +214,7 @@ static inline bool HammingSimilarityInit(RF_ScorerFunc* self, const RF_Kwargs* k
 {
     bool pad = *static_cast<bool*>(kwargs->context);
 
-    return similarity_init<rf::CachedHamming, int64_t>(self, str_count, str, pad);
+    return similarity_init<rf::CachedHamming, size_t>(self, str_count, str, pad);
 }
 
 static inline double hamming_normalized_similarity_func(const RF_String& str1, const RF_String& str2,
@@ -233,7 +233,7 @@ static inline bool HammingNormalizedSimilarityInit(RF_ScorerFunc* self, const RF
 }
 
 /* Indel */
-static inline int64_t indel_distance_func(const RF_String& str1, const RF_String& str2, int64_t score_cutoff)
+static inline size_t indel_distance_func(const RF_String& str1, const RF_String& str2, size_t score_cutoff)
 {
     return visitor(str1, str2, [&](auto s1, auto s2) {
         return rf::indel_distance(s1, s2, score_cutoff);
@@ -244,10 +244,10 @@ static inline bool IndelDistanceInit(RF_ScorerFunc* self, const RF_Kwargs*, int6
 {
 #ifdef RAPIDFUZZ_X64
     if (str_count != 1)
-        return multi_distance_init<rf::experimental::MultiIndel, int64_t>(self, str_count, str);
+        return multi_distance_init<rf::experimental::MultiIndel, size_t>(self, str_count, str);
 #endif
 
-    return distance_init<rf::CachedIndel, int64_t>(self, str_count, str);
+    return distance_init<rf::CachedIndel, size_t>(self, str_count, str);
 }
 static inline bool IndelMultiStringSupport(const RF_Kwargs*)
 {
@@ -276,8 +276,8 @@ static inline bool IndelNormalizedDistanceInit(RF_ScorerFunc* self, const RF_Kwa
     return normalized_distance_init<rf::CachedIndel, double>(self, str_count, str);
 }
 
-static inline int64_t indel_similarity_func(const RF_String& str1, const RF_String& str2,
-                                            int64_t score_cutoff)
+static inline size_t indel_similarity_func(const RF_String& str1, const RF_String& str2,
+                                            size_t score_cutoff)
 {
     return visitor(str1, str2, [&](auto s1, auto s2) {
         return rf::indel_similarity(s1, s2, score_cutoff);
@@ -288,10 +288,10 @@ static inline bool IndelSimilarityInit(RF_ScorerFunc* self, const RF_Kwargs*, in
 {
 #ifdef RAPIDFUZZ_X64
     if (str_count != 1)
-        return multi_similarity_init<rf::experimental::MultiIndel, int64_t>(self, str_count, str);
+        return multi_similarity_init<rf::experimental::MultiIndel, size_t>(self, str_count, str);
 #endif
 
-    return similarity_init<rf::CachedIndel, int64_t>(self, str_count, str);
+    return similarity_init<rf::CachedIndel, size_t>(self, str_count, str);
 }
 
 static inline double indel_normalized_similarity_func(const RF_String& str1, const RF_String& str2,
@@ -313,8 +313,8 @@ static inline bool IndelNormalizedSimilarityInit(RF_ScorerFunc* self, const RF_K
 }
 
 /* LCSseq */
-static inline int64_t lcs_seq_distance_func(const RF_String& str1, const RF_String& str2,
-                                            int64_t score_cutoff)
+static inline size_t lcs_seq_distance_func(const RF_String& str1, const RF_String& str2,
+                                            size_t score_cutoff)
 {
     return visitor(str1, str2, [&](auto s1, auto s2) {
         return rf::lcs_seq_distance(s1, s2, score_cutoff);
@@ -325,10 +325,10 @@ static inline bool LCSseqDistanceInit(RF_ScorerFunc* self, const RF_Kwargs*, int
 {
 #ifdef RAPIDFUZZ_X64
     if (str_count != 1)
-        return multi_distance_init<rf::experimental::MultiLCSseq, int64_t>(self, str_count, str);
+        return multi_distance_init<rf::experimental::MultiLCSseq, size_t>(self, str_count, str);
 #endif
 
-    return distance_init<rf::CachedLCSseq, int64_t>(self, str_count, str);
+    return distance_init<rf::CachedLCSseq, size_t>(self, str_count, str);
 }
 static inline bool LCSseqMultiStringSupport(const RF_Kwargs*)
 {
@@ -357,8 +357,8 @@ static inline bool LCSseqNormalizedDistanceInit(RF_ScorerFunc* self, const RF_Kw
     return normalized_distance_init<rf::CachedLCSseq, double>(self, str_count, str);
 }
 
-static inline int64_t lcs_seq_similarity_func(const RF_String& str1, const RF_String& str2,
-                                              int64_t score_cutoff)
+static inline size_t lcs_seq_similarity_func(const RF_String& str1, const RF_String& str2,
+                                              size_t score_cutoff)
 {
     return visitor(str1, str2, [&](auto s1, auto s2) {
         return rf::lcs_seq_similarity(s1, s2, score_cutoff);
@@ -369,10 +369,10 @@ static inline bool LCSseqSimilarityInit(RF_ScorerFunc* self, const RF_Kwargs*, i
 {
 #ifdef RAPIDFUZZ_X64
     if (str_count != 1)
-        return multi_similarity_init<rf::experimental::MultiLCSseq, int64_t>(self, str_count, str);
+        return multi_similarity_init<rf::experimental::MultiLCSseq, size_t>(self, str_count, str);
 #endif
 
-    return similarity_init<rf::CachedLCSseq, int64_t>(self, str_count, str);
+    return similarity_init<rf::CachedLCSseq, size_t>(self, str_count, str);
 }
 
 static inline double lcs_seq_normalized_similarity_func(const RF_String& str1, const RF_String& str2,
@@ -401,7 +401,7 @@ static inline rf::Editops hamming_editops_func(const RF_String& str1, const RF_S
 }
 
 static inline rf::Editops levenshtein_editops_func(const RF_String& str1, const RF_String& str2,
-                                                   int64_t score_hint)
+                                                   size_t score_hint)
 {
     return visitor(str1, str2, [&](auto s1, auto s2) {
         return rf::levenshtein_editops(s1, s2, score_hint);
@@ -423,7 +423,7 @@ static inline rf::Editops lcs_seq_editops_func(const RF_String& str1, const RF_S
 }
 
 /* Damerau Levenshtein */
-static inline int64_t osa_distance_func(const RF_String& str1, const RF_String& str2, int64_t score_cutoff)
+static inline size_t osa_distance_func(const RF_String& str1, const RF_String& str2, size_t score_cutoff)
 {
     return visitor(str1, str2, [&](auto s1, auto s2) {
         return rf::osa_distance(s1, s2, score_cutoff);
@@ -434,10 +434,10 @@ static inline bool OSADistanceInit(RF_ScorerFunc* self, const RF_Kwargs*, int64_
                                    const RF_String* str)
 {
 #ifdef RAPIDFUZZ_X64
-    if (str_count != 1) return multi_distance_init<rf::experimental::MultiOSA, int64_t>(self, str_count, str);
+    if (str_count != 1) return multi_distance_init<rf::experimental::MultiOSA, size_t>(self, str_count, str);
 #endif
 
-    return distance_init<rf::CachedOSA, int64_t>(self, str_count, str);
+    return distance_init<rf::CachedOSA, size_t>(self, str_count, str);
 }
 
 static inline bool OSAMultiStringSupport(const RF_Kwargs*)
@@ -467,7 +467,7 @@ static inline bool OSANormalizedDistanceInit(RF_ScorerFunc* self, const RF_Kwarg
     return normalized_distance_init<rf::CachedOSA, double>(self, str_count, str);
 }
 
-static inline int64_t osa_similarity_func(const RF_String& str1, const RF_String& str2, int64_t score_cutoff)
+static inline size_t osa_similarity_func(const RF_String& str1, const RF_String& str2, size_t score_cutoff)
 {
     return visitor(str1, str2, [&](auto s1, auto s2) {
         return rf::osa_similarity(s1, s2, score_cutoff);
@@ -479,10 +479,10 @@ static inline bool OSASimilarityInit(RF_ScorerFunc* self, const RF_Kwargs*, int6
 {
 #ifdef RAPIDFUZZ_X64
     if (str_count != 1)
-        return multi_similarity_init<rf::experimental::MultiOSA, int64_t>(self, str_count, str);
+        return multi_similarity_init<rf::experimental::MultiOSA, size_t>(self, str_count, str);
 #endif
 
-    return similarity_init<rf::CachedOSA, int64_t>(self, str_count, str);
+    return similarity_init<rf::CachedOSA, size_t>(self, str_count, str);
 }
 
 static inline double osa_normalized_similarity_func(const RF_String& str1, const RF_String& str2,
@@ -677,7 +677,7 @@ static inline bool JaroWinklerMultiStringSupport(const RF_Kwargs*)
 }
 
 /* Prefix */
-static inline int64_t prefix_distance_func(const RF_String& str1, const RF_String& str2, int64_t score_cutoff)
+static inline size_t prefix_distance_func(const RF_String& str1, const RF_String& str2, size_t score_cutoff)
 {
     return visitor(str1, str2, [&](auto s1, auto s2) {
         return rf::prefix_distance(s1, s2, score_cutoff);
@@ -686,7 +686,7 @@ static inline int64_t prefix_distance_func(const RF_String& str1, const RF_Strin
 static inline bool PrefixDistanceInit(RF_ScorerFunc* self, const RF_Kwargs*, int64_t str_count,
                                       const RF_String* str)
 {
-    return distance_init<rf::CachedPrefix, int64_t>(self, str_count, str);
+    return distance_init<rf::CachedPrefix, size_t>(self, str_count, str);
 }
 
 static inline double prefix_normalized_distance_func(const RF_String& str1, const RF_String& str2,
@@ -702,8 +702,8 @@ static inline bool PrefixNormalizedDistanceInit(RF_ScorerFunc* self, const RF_Kw
     return normalized_distance_init<rf::CachedPrefix, double>(self, str_count, str);
 }
 
-static inline int64_t prefix_similarity_func(const RF_String& str1, const RF_String& str2,
-                                             int64_t score_cutoff)
+static inline size_t prefix_similarity_func(const RF_String& str1, const RF_String& str2,
+                                             size_t score_cutoff)
 {
     return visitor(str1, str2, [&](auto s1, auto s2) {
         return rf::prefix_similarity(s1, s2, score_cutoff);
@@ -712,7 +712,7 @@ static inline int64_t prefix_similarity_func(const RF_String& str1, const RF_Str
 static inline bool PrefixSimilarityInit(RF_ScorerFunc* self, const RF_Kwargs*, int64_t str_count,
                                         const RF_String* str)
 {
-    return similarity_init<rf::CachedPrefix, int64_t>(self, str_count, str);
+    return similarity_init<rf::CachedPrefix, size_t>(self, str_count, str);
 }
 
 static inline double prefix_normalized_similarity_func(const RF_String& str1, const RF_String& str2,
@@ -729,8 +729,8 @@ static inline bool PrefixNormalizedSimilarityInit(RF_ScorerFunc* self, const RF_
 }
 
 /* Postfix */
-static inline int64_t postfix_distance_func(const RF_String& str1, const RF_String& str2,
-                                            int64_t score_cutoff)
+static inline size_t postfix_distance_func(const RF_String& str1, const RF_String& str2,
+                                            size_t score_cutoff)
 {
     return visitor(str1, str2, [&](auto s1, auto s2) {
         return rf::postfix_distance(s1, s2, score_cutoff);
@@ -739,7 +739,7 @@ static inline int64_t postfix_distance_func(const RF_String& str1, const RF_Stri
 static inline bool PostfixDistanceInit(RF_ScorerFunc* self, const RF_Kwargs*, int64_t str_count,
                                        const RF_String* str)
 {
-    return distance_init<rf::CachedPostfix, int64_t>(self, str_count, str);
+    return distance_init<rf::CachedPostfix, size_t>(self, str_count, str);
 }
 
 static inline double postfix_normalized_distance_func(const RF_String& str1, const RF_String& str2,
@@ -755,8 +755,8 @@ static inline bool PostfixNormalizedDistanceInit(RF_ScorerFunc* self, const RF_K
     return normalized_distance_init<rf::CachedPostfix, double>(self, str_count, str);
 }
 
-static inline int64_t postfix_similarity_func(const RF_String& str1, const RF_String& str2,
-                                              int64_t score_cutoff)
+static inline size_t postfix_similarity_func(const RF_String& str1, const RF_String& str2,
+                                              size_t score_cutoff)
 {
     return visitor(str1, str2, [&](auto s1, auto s2) {
         return rf::postfix_similarity(s1, s2, score_cutoff);
@@ -765,7 +765,7 @@ static inline int64_t postfix_similarity_func(const RF_String& str1, const RF_St
 static inline bool PostfixSimilarityInit(RF_ScorerFunc* self, const RF_Kwargs*, int64_t str_count,
                                          const RF_String* str)
 {
-    return similarity_init<rf::CachedPostfix, int64_t>(self, str_count, str);
+    return similarity_init<rf::CachedPostfix, size_t>(self, str_count, str);
 }
 
 static inline double postfix_normalized_similarity_func(const RF_String& str1, const RF_String& str2,
